==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/ko.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "문서",
"Can't create document" => "문서를 만들 수 없음",
"You don't have permission to rename this document" => "이 문서의 이름을 변경할 권한이 없습니다",
"Directory saved successfully." => "디렉터리를 저장하였습니다.",
"An error occurred while changing directory." => "디렉터리를 변경하는 중 오류가 발생하였습니다.",
"Saved" => "저장됨",
"Format filter server is down or misconfigured" => "포맷 필터 서버를 사용할 수 없거나 설정이 잘못되었습니다",
"Conversion failed. Check log for details." => "변환이 실패하였습니다. 자세한 정보는 로그를 참조하십시오.",
"Saving..." => "저장 중...",
"Failed to load documents." => "문서를 불러올 수 없습니다.",
"No documents were found. Upload or create a document to get started!" => "문서를 찾을 수 없습니다. 문서를 업로드하거나 새 문서를 만들 수 있습니다!",
"No connection to server. Trying to reconnect." => "서버에 연결되지 않았습니다. 재연결을 시도합니다.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "편집기 모드에서 이 페이지를 벗어나면 데이터가 저장되지 않을 수도 있습니다. '닫기' 단추를 누르는 것을 추천합니다.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "이 문서를 불러올 수 없습니다. 외부 ODT 편집기로 불러올 수 있는지 확인해 보십시오. 최근에 공유가 해제되었거나 삭제되었을 수도 있습니다.",
"Save" => "저장",
"Loading documents..." => "문서 불러오는 중...",
"'.' is an invalid file name." => "'.' 는 올바르지 않은 파일 이름입니다.",
"File name cannot be empty." => "파일 이름이 비어 있을 수 없습니다.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "폴더 이름이 올바르지 않습니다. 이름에 문자 '\\', '/', '<', '>', ':', '\"', '|', '? ', '*'는 사용할 수 없습니다.",
"Align Left" => "왼쪽 정렬",
"Alignment" => "정렬",
"Align Right" => "오른쪽 정렬",
"Annotate" => "주석",
"Background" => "배경",
"Bold" => "굵게",
"Bottom" => "아래",
"Cancel" => "취소",
"Center" => "중앙",
"Clone" => "복제",
"Clone this Style" => "이 스타일 복제",
"Close" => "닫기",
"Color" => "색",
"Create" => "만들기",
"Decrease Indent" => "들여쓰기 감소",
"Default Style" => "기본 스타일",
"Delete" => "삭제",
"Family" => "종류",
"Font" => "글꼴",
"Font Effects" => "글꼴 효과",
"Format" => "서식",
"Increase Indent" => "들여쓰기 증가",
"Insert Image" => "그림 삽입",
"Invite Members" => "구성원 초대",
"Italic" => "이탤릭",
"Justified" => "양쪽 맞춤",
"Justify" => "맞춤",
"Left" => "왼쪽",
"Loading" => "불러오는 중",
"Members" => "구성원",
"New Name:" => "새 이름:",
"OK" => "확인",
"Open" => "열기",
"Options" => "옵션",
"Paragraph..." => "문단...",
"Paragraph Styles" => "문단 스타일",
"Redo" => "다시 실행",
"Right" => "오른쪽",
"Size" => "크기",
"Spacing" => "간격",
"Strikethrough" => "취소선",
"Style" => "스타일",
"Text" => "텍스트",
"Top" => "위",
"Underline" => "밑줄",
"Undo" => "실행 취소",
"Unknown Author" => "알 수 없는 작성자",
"Edit" => "편집",
"Share" => "공유",
"guest" => "손님",
"MS Word support (requires openOffice/libreOffice)" => "MS Word 지원(OpenOffice/LibreOffice 필요)",
"Local" => "로컬",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "이 서버에 OpenOffice/LibreOffice가 설치되어 있습니다. config.php의 preview_libreoffice_path에 실행 파일 경로를 지정하십시오",
"External" => "외부",
"openOffice/libreOffice is installed on external server running a format filter server" => "OpenOffice/LibreOffice가 포맷 필터 서버가 설치된 외부 서버에 있음",
"Disabled" => "비활성화",
"No MS Word support" => "MS Word 지원 없음",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "서버 URL",
"Apply and test" => "적용 및 시험",
"New document" => "새 문서",
"Upload (max. %s)" => "업로드(최대 %s)",
"Upload" => "업로드",
"Save new documents to" => "다음에 새 문서 저장",
"Wrong password. Please retry." => "암호가 잘못되었습니다. 다시 시도하십시오.",
"Password" => "암호",
"Guest %s" => "손님 %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "이 링크는 만료되었거나 존재하지 않았습니다. 이 링크를 공유한 사람에게 문의하십시오.",
"Advanced feature-set" => "고급 기능",
"(Unstable)" => "(불안정)"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";

==> owncloud-app-documents-1%3A8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/ko.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "문서",
"Can't create document" => "문서를 만들 수 없음",
"You don't have permission to rename this document" => "이 문서의 이름을 변경할 권한이 없습니다",
"Directory saved successfully." => "디렉터리를 저장하였습니다.",
"An error occurred while changing directory." => "디렉터리를 변경하는 중 오류가 발생하였습니다.",
"Saved" => "저장됨",
"Format filter server is down or misconfigured" => "포맷 필터 서버를 사용할 수 없거나 설정이 잘못되었습니다",
"Conversion failed. Check log for details." => "변환이 실패하였습니다. 자세한 정보는 로그를 참조하십시오.",
"Saving..." => "저장 중...",
"Failed to load documents." => "문서를 불러올 수 없습니다.",
"No documents were found. Upload or create a document to get started!" => "문서를 찾을 수 없습니다. 문서를 업로드하거나 새 문서를 만들 수 있습니다!",
"No connection to server. Trying to reconnect." => "서버에 연결되지 않았습니다. 재연결을 시도합니다.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "편집기 모드에서 이 페이지를 벗어나면 데이터가 저장되지 않을 수도 있습니다. '닫기' 단추를 누르는 것을 추천합니다.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "이 문서를 불러올 수 없습니다. 외부 ODT 편집기로 불러올 수 있는지 확인해 보십시오. 최근에 공유가 해제되었거나 삭제되었을 수도 있습니다.",
"Save" => "저장",
"Loading documents..." => "문서 불러오는 중...",
"'.' is an invalid file name." => "'.' 는 올바르지 않은 파일 이름입니다.",
"File name cannot be empty." => "파일 이름이 비어 있을 수 없습니다.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "폴더 이름이 올바르지 않습니다. 이름에 문자 '\\', '/', '<', '>', ':', '\"', '|', '? ', '*'는 사용할 수 없습니다.",
"Align Left" => "왼쪽 정렬",
"Alignment" => "정렬",
"Align Right" => "오른쪽 정렬",
"Annotate" => "주석",
"Background" => "배경",
"Bold" => "굵게",
"Bottom" => "아래",
"Cancel" => "취소",
"Center" => "중앙",
"Clone" => "복제",
"Clone this Style" => "이 스타일 복제",
"Close" => "닫기",
"Color" => "색",
"Create" => "만들기",
"Decrease Indent" => "들여쓰기 감소",
"Default Style" => "기본 스타일",
"Delete" => "삭제",
"Family" => "종류",
"Font" => "글꼴",
"Font Effects" => "글꼴 효과",
"Format" => "서식",
"Increase Indent" => "들여쓰기 증가",
"Insert Image" => "그림 삽입",
"Invite Members" => "구성원 초대",
"Italic" => "이탤릭",
"Justified" => "양쪽 맞춤",
"Justify" => "맞춤",
"Left" => "왼쪽",
"Loading" => "불러오는 중",
"Members" => "구성원",
"New Name:" => "새 이름:",
"OK" => "확인",
"Open" => "열기",
"Options" => "옵션",
"Paragraph..." => "문단...",
"Paragraph Styles" => "문단 스타일",
"Redo" => "다시 실행",
"Right" => "오른쪽",
"Size" => "크기",
"Spacing" => "간격",
"Strikethrough" => "취소선",
"Style" => "스타일",
"Text" => "텍스트",
"Top" => "위",
"Underline" => "밑줄",
"Undo" => "실행 취소",
"Unknown Author" => "알 수 없는 작성자",
"Shared" => "공유됨",
"Error" => "오류",
"Error while sharing" => "공유하는 중 오류 발생",
"Error while unsharing" => "공유 해제하는 중 오류 발생",
"Error while changing permissions" => "권한 변경하는 중 오류 발생",
"Shared with you and the group {group} by {owner}" => "{owner} 님이 여러분 및 그룹 {group}와(과) 공유 중",
"Shared with you by {owner}" => "{owner} 님이 공유 중",
"Share with users or groups …" => "사용자 및 그룹과 공유...",
"Share with users, groups or remote users …" => "사용자, 그룹 및 원격 사용자와 공유...",
"Share" => "공유",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "username@example.com/owncloud 형식으로 다른 ownCloud 사용자와 공유할 수 있습니다",
"Share link" => "링크 공유",
"The public link will expire no later than {days} days after it is created" => "공개 링크를 만든 후 최대 {days}일까지 유지됩니다",
"Link" => "링크",
"Password protect" => "암호 보호",
"Password" => "암호",
"Choose a password for the public link" => "공개 링크 암호를 입력하십시오",
"Allow editing" => "편집 허용",
"Email link to person" => "이메일 주소",
"Send" => "보내기",
"Set expiration date" => "만료 날짜 설정",
"Expiration" => "만료",
"Expiration date" => "만료 날짜",
"An error occured. Please try again" => "오류가 발생하였습니다. 다시 시도하십시오.",
"Adding user..." => "사용자 추가 중...",
"group" => "그룹",
"remote" => "원격",
"Resharing is not allowed" => "다시 공유할 수 없습니다",
"Shared in {item} with {user}" => "{user} 님과 {item}에서 공유 중",
"Unshare" => "공유 해제",
"notify by email" => "이메일로 알림",
"can share" => "공유 가능",
"can edit" => "편집 가능",
"access control" => "접근 제어",
"create" => "생성",
"change" => "변경",
"delete" => "삭제",
"Password protected" => "암호로 보호됨",
"Error unsetting expiration date" => "만료 날짜 해제 오류",
"Error setting expiration date" => "만료 날짜 설정 오류",
"Sending ..." => "전송 중...",
"Email sent" => "이메일 발송됨",
"Warning" => "경고",
"Edit" => "편집",
"guest" => "손님",
"MS Word support (requires openOffice/libreOffice)" => "MS Word 지원(OpenOffice/LibreOffice 필요)",
"Local" => "로컬",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "이 서버에 OpenOffice/LibreOffice가 설치되어 있습니다. config.php의 preview_libreoffice_path에 실행 파일 경로를 지정하십시오",
"External" => "외부",
"openOffice/libreOffice is installed on external server running a format filter server" => "OpenOffice/LibreOffice가 포맷 필터 서버가 설치된 외부 서버에 있음",
"Disabled" => "비활성화",
"No MS Word support" => "MS Word 지원 없음",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "서버 URL",
"Apply and test" => "적용 및 시험",
"New document" => "새 문서",
"Upload (max. %s)" => "업로드(최대 %s)",
"Upload" => "업로드",
"Save new documents to" => "다음에 새 문서 저장",
"Wrong password. Please retry." => "암호가 잘못되었습니다. 다시 시도하십시오.",
"Guest %s" => "손님 %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "이 링크는 만료되었거나 존재하지 않았습니다. 이 링크를 공유한 사람에게 문의하십시오.",
"Advanced feature-set" => "고급 기능",
"(Unstable)" => "(불안정)"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
